==> PacketStreams-0.1.8-sources.jar: org/openzen/packetstreams/qpsp/Constants.java <==
/* MIT licensed - see LICENSE in the project root directory. */
package org.openzen.packetstreams.qpsp;

/**
 * Contains protocol constants
 */
public class Constants {
	private Constants() {}
	
	public static final int VERSION = 1;
	
	public static final int STREAM_SETUP = 0;
	public static final int STREAM_INIT = 1;
	
	public static final byte PACKET_OPEN = 1;
	public static final byte PACKET_QUICKOPEN = 2;
	public static final byte PACKET_SERVICEINFO = 3;
	public static final byte PACKET_START = 4;
	public static final byte PACKET_DATA = 5;
	public static final byte PACKET_ACK = 6;
	public static final byte PACKET_CLOSE = 7;
	public static final byte PACKET_FRAGSTART = 8;
	public static final byte PACKET_FRAGPART = 9;
	public static final byte PACKET_FRAGEND = 10;
	
	public static final byte PACKET_INITIALIZED = 16;
	public static final byte PACKET_KEEPALIVE = 17;
	
	public static final int CLOSE_REQUESTED_BY_PEER = 0;
	public static final int CLOSE_REQUESTED_BY_APPLICATION = 1;
	public static final int CLOSE_PING_TIMEOUT = 2;
	public static final int CLOSE_PROTOCOL_ERROR = 3;
	public static final int CLOSE_SESSION_CLOSED = 4;
	public static final int CLOSE_SERVICE_NOT_FOUND = 5;
	public static final int CLOSE_PACKET_SIZE_EXCEEDED = 6;
	public static final int CLOSE_BUFFER_SIZE_EXCEEDED = 7;
	public static final int CLOSE_INTERNAL_ERROR = 8;
	public static final int CLOSE_SERVER_CLOSING = 9;
	public static final int CLOSE_UNKNOWN_REASON = 10;
	
	public static final int SERVICEFLAG_CACHEABLE = 1;
}

==> PacketStreams-0.2.3-sources.jar: org/openzen/packetstreams/qpsp/Constants.java <==
/* MIT licensed - see LICENSE in the project root directory. */
package org.openzen.packetstreams.qpsp;

/**
 * Contains protocol constants
 */
public class Constants {
	private Constants() {}
	
	public static final int VERSION = 1;
	
	public static final int CONNECTION_SETUP = 2;
	public static final int CONNECTION_INIT = 3;
	
	public static final byte PACKET_OPEN = 1;
	public static final byte PACKET_QUICKOPEN = 2;
	public static final byte PACKET_SERVICEINFO = 3;
	public static final byte PACKET_START = 4;
	public static final byte PACKET_DATA = 5;
	public static final byte PACKET_ACK = 6;
	public static final byte PACKET_CLOSE_STREAM = 7;
	public static final byte PACKET_FRAGSTART = 8;
	public static final byte PACKET_FRAGPART = 9;
	public static final byte PACKET_FRAGEND = 10;
	public static final byte PACKET_STOP_WAITING = 11;
	public static final byte PACKET_CLOSE_CONNECTION = 12;
	
	public static final byte PACKET_INITIALIZED = 16;
	public static final byte PACKET_KEEPALIVE = 17;
	
	public static final int CLOSE_REQUESTED_BY_PEER = 0;
	public static final int CLOSE_REQUESTED_BY_APPLICATION = 1;
	public static final int CLOSE_PING_TIMEOUT = 2;
	public static final int CLOSE_PROTOCOL_ERROR = 3;
	public static final int CLOSE_SESSION_CLOSED = 4;
	public static final int CLOSE_SERVICE_NOT_FOUND = 5;
	public static final int CLOSE_PACKET_SIZE_EXCEEDED = 6;
	public static final int CLOSE_BUFFER_SIZE_EXCEEDED = 7;
	public static final int CLOSE_INTERNAL_ERROR = 8;
	public static final int CLOSE_SERVER_CLOSING = 9;
	public static final int CLOSE_UNKNOWN_REASON = 10;
	public static final int CLOSE_CONNECTION_TIMEOUT = 11;
	
	public static final int SERVICEFLAG_CACHEABLE = 1;
}
